@@ -1,12 +1,12 @@
 #include "kactioncollectiontest.h"
 
-#include <QtTestWidgets>
 #include <QAction>
 #include <QPointer>
 #include <QSignalSpy>
+#include <QtTestWidgets>
 
-#include <ksharedconfig.h>
-#include <kstandardaction.h>
+#include <KSharedConfig>
+#include <KStandardAction>
 
 void tst_KActionCollection::init()
 {
@@ -41,6 +41,18 @@ void tst_KActionCollection::clear()
     QVERIFY(action7.isNull());
 }
 
+void tst_KActionCollection::addStandardActionFunctorSignal()
+{
+    bool received = false;
+    QAction *a = collection->addAction(KStandardAction::New, QStringLiteral("test"), this, [&]() {
+        received = true;
+    });
+    a->trigger();
+    QVERIFY(received);
+    delete a;
+    QVERIFY(collection->isEmpty());
+}
+
 void tst_KActionCollection::deleted()
 {
     // Delete action -> automatically removed from collection
@@ -60,7 +72,7 @@ void tst_KActionCollection::deleted()
     // and that widget gets deleted first.
     myWidget = new QWidget(nullptr);
     QWidget *myAssociatedWidget = new QWidget(myWidget); // child widget
-    action = new QAction(/*i18n()*/ QStringLiteral("Foo"), myWidget);  // child action
+    action = new QAction(/*i18n()*/ QStringLiteral("Foo"), myWidget); // child action
     collection->addAction(QStringLiteral("foo"), action);
     collection->addAssociatedWidget(myAssociatedWidget);
     QVERIFY(myAssociatedWidget->actions().contains(action));
@@ -213,7 +225,7 @@ KConfigGroup tst_KActionCollection::clearConfig()
 
 void tst_KActionCollection::testSetShortcuts()
 {
-    QAction *action = new QAction(/*i18n*/(QStringLiteral("Next Unread &Folder")), this);
+    QAction *action = new QAction(/*i18n*/ (QStringLiteral("Next Unread &Folder")), this);
     collection->addAction(QStringLiteral("go_next_unread_folder"), action);
     collection->setDefaultShortcut(action, QKeySequence(Qt::ALT | Qt::Key_Plus));
     QList<QKeySequence> shortcut = action->shortcuts();
@@ -230,7 +242,7 @@ void tst_KActionCollection::testSetShortcuts()
 void tst_KActionCollection::implicitStandardActionInsertionUsingCreate()
 {
     KActionCollection collection(static_cast<QObject *>(nullptr));
-    QAction *a = KStandardAction::create(KStandardAction::Undo, qApp, SLOT(quit()), &collection);
+    QAction *a = KStandardAction::create(KStandardAction::Undo, qApp, &QCoreApplication::quit, &collection);
     QVERIFY(a);
 
     QVERIFY(a->parent() == &collection);
@@ -293,4 +305,3 @@ void tst_KActionCollection::shouldEmitSignals()
 }
 
 QTEST_MAIN(tst_KActionCollection)
-
