@@ -1,32 +1,20 @@
-/* This file is part of the KDE libraries
-    Copyright (c) 2006 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2006 David Faure <faure@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kmainwindow_unittest.h"
 
-#include <QTest>
+#include <KConfigGroup>
+#include <KSharedConfig>
 #include <QEventLoopLocker>
-#include <kmainwindow.h>
-#include <QStatusBar>
 #include <QResizeEvent>
+#include <QStatusBar>
+#include <QTest>
+#include <kmainwindow.h>
 #include <ktoolbar.h>
-#include <ksharedconfig.h>
-#include <kconfiggroup.h>
 
 QTEST_MAIN(KMainWindow_UnitTest)
 
@@ -104,8 +92,9 @@ static bool s_mainWindowDeleted;
 class MyMainWindow : public KMainWindow
 {
 public:
-    MyMainWindow() : KMainWindow(),
-        m_queryClosedCalled(false)
+    MyMainWindow()
+        : KMainWindow()
+        , m_queryClosedCalled(false)
     {
     }
     bool queryClose() override
@@ -113,7 +102,7 @@ public:
         m_queryClosedCalled = true;
         return true;
     }
-    ~MyMainWindow()
+    ~MyMainWindow() override
     {
         s_mainWindowDeleted = true;
     }
@@ -176,6 +165,28 @@ void KMainWindow_UnitTest::testSaveWindowSize()
     QTRY_COMPARE(mw2.size(), QSize(800, 600));
 }
 
+void KMainWindow_UnitTest::testSaveWindowSizeInStateConfig()
+{
+    QCOMPARE(KSharedConfig::openConfig()->name(), QStringLiteral("kmainwindow_unittestrc"));
+    KConfigGroup cfg(KSharedConfig::openConfig(), "testSaveWindowSizeInStateConfig");
+    cfg.deleteGroup();
+    QVERIFY(cfg.isValid());
+
+    {
+        MyMainWindow mw;
+        mw.show();
+        mw.reallyResize(800, 600);
+        mw.setStateConfigGroup(QStringLiteral("StateConfigGroup"));
+        mw.saveMainWindowSettings(cfg);
+        mw.close();
+    }
+
+    const KConfigGroup stateGrp = KSharedConfig::openStateConfig()->group(QStringLiteral("StateConfigGroup"));
+    QVERIFY(stateGrp.exists());
+    QVERIFY(stateGrp.hasKey("State"));
+    QVERIFY(!cfg.hasKey("State"));
+}
+
 void KMainWindow_UnitTest::testAutoSaveSettings()
 {
     const QString group(QStringLiteral("AutoSaveTestGroup"));
