@@ -17,48 +17,53 @@
 
 #include "kactioncollection.h"
 
+#include "debug.h"
 #include "kactioncategory.h"
 #include "kxmlguiclient.h"
 #include "kxmlguifactory.h"
-#include "debug.h"
 
-#include <kauthorized.h>
-#include <kconfiggroup.h>
+#include <KAuthorized>
+#include <KConfigGroup>
 #if HAVE_GLOBALACCEL
-# include <kglobalaccel.h>
+#include <KGlobalAccel>
 #endif
-#include <ksharedconfig.h>
+#include <KSharedConfig>
 
 #include <QDomDocument>
-#include <QSet>
 #include <QGuiApplication>
-#include <QMap>
 #include <QList>
+#include <QMap>
 #include <QMetaMethod>
+#include <QSet>
 
-#include <stdio.h>
+#include <cstdio>
+
+static bool actionHasGlobalShortcut(const QAction *action)
+{
+#if HAVE_GLOBALACCEL
+    return KGlobalAccel::self()->hasShortcut(action);
+#else
+    return false;
+#endif
+}
 
 class KActionCollectionPrivate
 {
 public:
     KActionCollectionPrivate()
-        : m_parentGUIClient(nullptr),
-          configGroup(QStringLiteral("Shortcuts")),
-          configIsGlobal(false),
-          connectTriggered(false),
-          connectHovered(false),
-          q(nullptr)
+        : m_parentGUIClient(nullptr)
+        , configGroup(QStringLiteral("Shortcuts"))
+        , configIsGlobal(false)
+        , connectTriggered(false)
+        , connectHovered(false)
+        , q(nullptr)
 
     {
     }
 
     void setComponentForAction(QAction *action)
     {
-#if HAVE_GLOBALACCEL
-        bool hasGlobalShortcut = KGlobalAccel::self()->hasShortcut(action);
-#else
-        bool hasGlobalShortcut = false;
-#endif
+        const bool hasGlobalShortcut = actionHasGlobalShortcut(action);
         if (!hasGlobalShortcut) {
             action->setProperty("componentName", m_componentName);
             action->setProperty("componentDisplayName", m_componentDisplayName);
@@ -121,8 +126,6 @@ KActionCollection::KActionCollection(const KXMLGUIClient *parent)
 KActionCollection::~KActionCollection()
 {
     KActionCollectionPrivate::s_allCollections.removeAll(this);
-
-    delete d;
 }
 
 void KActionCollection::clear()
@@ -161,14 +164,15 @@ bool KActionCollection::isEmpty() const
 
 void KActionCollection::setComponentName(const QString &cName)
 {
-    if (count() > 0) {
-        // Its component name is part of an action's signature in the context of
-        // global shortcuts and the semantics of changing an existing action's
-        // signature are, as it seems, impossible to get right.
-        // As of now this only matters for global shortcuts. We could
-        // thus relax the requirement and only refuse to change the component data
-        // if we have actions with global shortcuts in this collection.
-        qCWarning(DEBUG_KXMLGUI) << "KActionCollection::setComponentName does not work on a KActionCollection containing actions!" << cName;
+    for (QAction *a : std::as_const(d->actions)) {
+        if (actionHasGlobalShortcut(a)) {
+            // Its component name is part of an action's signature in the context of
+            // global shortcuts and the semantics of changing an existing action's
+            // signature are, as it seems, impossible to get right.
+            qCWarning(DEBUG_KXMLGUI) << "KActionCollection::setComponentName does not work on a KActionCollection containing actions with global shortcuts!"
+                                     << cName;
+            break;
+        }
     }
 
     if (!cName.isEmpty()) {
@@ -209,10 +213,10 @@ QList<QAction *> KActionCollection::actions() const
     return d->actions;
 }
 
-const QList< QAction * > KActionCollection::actionsWithoutGroup() const
+const QList<QAction *> KActionCollection::actionsWithoutGroup() const
 {
     QList<QAction *> ret;
-    for (QAction *action : qAsConst(d->actions)) {
+    for (QAction *action : std::as_const(d->actions)) {
         if (!action->actionGroup()) {
             ret.append(action);
         }
@@ -220,10 +224,10 @@ const QList< QAction * > KActionCollection::actionsWithoutGroup() const
     return ret;
 }
 
-const QList< QActionGroup * > KActionCollection::actionGroups() const
+const QList<QActionGroup *> KActionCollection::actionGroups() const
 {
     QSet<QActionGroup *> set;
-    for (QAction *action : qAsConst(d->actions)) {
+    for (QAction *action : std::as_const(d->actions)) {
         if (action->actionGroup()) {
             set.insert(action->actionGroup());
         }
@@ -245,7 +249,6 @@ QAction *KActionCollection::addAction(const QString &name, QAction *action)
         indexName = objectName;
 
     } else {
-
         // A name was provided. Check against objectName.
         if ((!objectName.isEmpty()) && (objectName != indexName)) {
             // The user specified a new name and the action already has a
@@ -258,7 +261,8 @@ QAction *KActionCollection::addAction(const QString &name, QAction *action)
                 // In debug mode assert
                 Q_ASSERT(!KGlobalAccel::self()->hasShortcut(action));
                 // In release mode keep the old name
-                qCCritical(DEBUG_KXMLGUI) << "Changing action name from " << objectName << " to " << indexName << "\nignored because of active global shortcut.";
+                qCCritical(DEBUG_KXMLGUI) << "Changing action name from " << objectName << " to " << indexName
+                                          << "\nignored because of active global shortcut.";
                 indexName = objectName;
             }
 #endif
@@ -311,26 +315,26 @@ QAction *KActionCollection::addAction(const QString &name, QAction *action)
     d->actionByName.insert(indexName, action);
     d->actions.append(action);
 
-    for (QWidget *widget : qAsConst(d->associatedWidgets)) {
+    for (QWidget *widget : std::as_const(d->associatedWidgets)) {
         widget->addAction(action);
     }
 
-    connect(action, SIGNAL(destroyed(QObject*)), SLOT(_k_actionDestroyed(QObject*)));
+    connect(action, &QObject::destroyed, this, [this](QObject *obj) {
+        d->_k_actionDestroyed(obj);
+    });
 
     d->setComponentForAction(action);
 
     if (d->connectHovered) {
-        connect(action, &QAction::hovered,
-                this, &KActionCollection::slotActionHovered);
+        connect(action, &QAction::hovered, this, &KActionCollection::slotActionHovered);
     }
 
     if (d->connectTriggered) {
-        connect(action, &QAction::triggered,
-                this, &KActionCollection::slotActionTriggered);
+        connect(action, &QAction::triggered, this, &KActionCollection::slotActionTriggered);
     }
 
-    emit inserted(action);
-    emit changed();
+    Q_EMIT inserted(action);
+    Q_EMIT changed();
     return action;
 }
 
@@ -353,16 +357,16 @@ QAction *KActionCollection::takeAction(QAction *action)
     }
 
     // Remove the action from all widgets
-    for (QWidget *widget : qAsConst(d->associatedWidgets)) {
+    for (QWidget *widget : std::as_const(d->associatedWidgets)) {
         widget->removeAction(action);
     }
 
     action->disconnect(this);
 
 #if KXMLGUI_BUILD_DEPRECATED_SINCE(5, 0)
-    emit removed(action);   //deprecated
+    Q_EMIT removed(action); // deprecated
 #endif
-    emit changed();
+    Q_EMIT changed();
     return action;
 }
 
@@ -372,8 +376,7 @@ QAction *KActionCollection::addAction(KStandardAction::StandardAction actionType
     return action;
 }
 
-QAction *KActionCollection::addAction(KStandardAction::StandardAction actionType, const QString &name,
-                                      const QObject *receiver, const char *member)
+QAction *KActionCollection::addAction(KStandardAction::StandardAction actionType, const QString &name, const QObject *receiver, const char *member)
 {
     // pass 0 as parent, because if the parent is a KActionCollection KStandardAction::create automatically
     // adds the action to it under the default name. We would trigger the
@@ -404,7 +407,7 @@ QKeySequence KActionCollection::defaultShortcut(QAction *action) const
 
 QList<QKeySequence> KActionCollection::defaultShortcuts(QAction *action) const
 {
-    return action->property("defaultShortcuts").value<QList<QKeySequence> >();
+    return action->property("defaultShortcuts").value<QList<QKeySequence>>();
 }
 
 void KActionCollection::setDefaultShortcut(QAction *action, const QKeySequence &shortcut)
@@ -458,14 +461,13 @@ void KActionCollection::importGlobalShortcuts(KConfigGroup *config)
         return;
     }
 
-    for (QMap<QString, QAction *>::ConstIterator it = d->actionByName.constBegin();
-            it != d->actionByName.constEnd(); ++it) {
+    for (QMap<QString, QAction *>::ConstIterator it = d->actionByName.constBegin(); it != d->actionByName.constEnd(); ++it) {
         QAction *action = it.value();
         if (!action) {
             continue;
         }
 
-        QString actionName = it.key();
+        const QString &actionName = it.key();
 
         if (isShortcutsConfigurable(action)) {
             QString entry = config->readEntry(actionName, QString());
@@ -493,15 +495,14 @@ void KActionCollection::readSettings(KConfigGroup *config)
         return;
     }
 
-    for (QMap<QString, QAction *>::ConstIterator it = d->actionByName.constBegin();
-            it != d->actionByName.constEnd(); ++it) {
+    for (QMap<QString, QAction *>::ConstIterator it = d->actionByName.constBegin(); it != d->actionByName.constEnd(); ++it) {
         QAction *action = it.value();
         if (!action) {
             continue;
         }
 
         if (isShortcutsConfigurable(action)) {
-            QString actionName = it.key();
+            const QString &actionName = it.key();
             QString entry = config->readEntry(actionName, QString());
             if (!entry.isEmpty()) {
                 action->setShortcuts(QKeySequence::listFromString(entry));
@@ -511,7 +512,7 @@ void KActionCollection::readSettings(KConfigGroup *config)
         }
     }
 
-    //qCDebug(DEBUG_KXMLGUI) << " done";
+    // qCDebug(DEBUG_KXMLGUI) << " done";
 }
 
 void KActionCollection::exportGlobalShortcuts(KConfigGroup *config, bool writeAll) const
@@ -522,14 +523,12 @@ void KActionCollection::exportGlobalShortcuts(KConfigGroup *config, bool writeAl
         return;
     }
 
-    for (QMap<QString, QAction *>::ConstIterator it = d->actionByName.constBegin();
-            it != d->actionByName.constEnd(); ++it) {
-
+    for (QMap<QString, QAction *>::ConstIterator it = d->actionByName.constBegin(); it != d->actionByName.constEnd(); ++it) {
         QAction *action = it.value();
         if (!action) {
             continue;
         }
-        QString actionName = it.key();
+        const QString &actionName = it.key();
 
         // If the action name starts with unnamed- spit out a warning. That name
         // will change at will and will break loading writing
@@ -594,14 +593,13 @@ bool KActionCollectionPrivate::writeKXMLGUIConfigFile()
     QDomElement elem = KXMLGUIFactory::actionPropertiesElement(doc);
 
     // now, iterate through our actions
-    for (QMap<QString, QAction *>::ConstIterator it = actionByName.constBegin();
-            it != actionByName.constEnd(); ++it) {
+    for (QMap<QString, QAction *>::ConstIterator it = actionByName.constBegin(); it != actionByName.constEnd(); ++it) {
         QAction *action = it.value();
         if (!action) {
             continue;
         }
 
-        QString actionName = it.key();
+        const QString &actionName = it.key();
 
         // If the action name starts with unnamed- spit out a warning and ignore
         // it. That name will change at will and will break loading writing
@@ -611,12 +609,11 @@ bool KActionCollectionPrivate::writeKXMLGUIConfigFile()
         }
 
         bool bSameAsDefault = (action->shortcuts() == q->defaultShortcuts(action));
-        qCDebug(DEBUG_KXMLGUI) << "name = " << actionName
-                 << " shortcut = " << QKeySequence::listToString(action->shortcuts())
+        qCDebug(DEBUG_KXMLGUI) << "name = " << actionName << " shortcut = " << QKeySequence::listToString(action->shortcuts())
 #if HAVE_GLOBALACCEL
-                 << " globalshortcut = " << QKeySequence::listToString(KGlobalAccel::self()->shortcut(action))
+                               << " globalshortcut = " << QKeySequence::listToString(KGlobalAccel::self()->shortcut(action))
 #endif
-                 << " def = " << QKeySequence::listToString(q->defaultShortcuts(action));
+                               << " def = " << QKeySequence::listToString(q->defaultShortcuts(action));
 
         // now see if this element already exists
         // and create it if necessary (unless bSameAsDefault)
@@ -627,7 +624,7 @@ bool KActionCollectionPrivate::writeKXMLGUIConfigFile()
 
         if (bSameAsDefault) {
             act_elem.removeAttribute(attrShortcut);
-            //qCDebug(DEBUG_KXMLGUI) << "act_elem.attributes().count() = " << act_elem.attributes().count();
+            // qCDebug(DEBUG_KXMLGUI) << "act_elem.attributes().count() = " << act_elem.attributes().count();
             if (act_elem.attributes().count() == 1) {
                 elem.removeChild(act_elem);
             }
@@ -640,7 +637,7 @@ bool KActionCollectionPrivate::writeKXMLGUIConfigFile()
     KXMLGUIFactory::saveConfigFile(doc, kxmlguiClient->localXMLFile(), q->componentName());
     // and since we just changed the xml file clear the dom we have in memory
     // it'll be rebuilt if needed
-    const_cast<KXMLGUIClient*>(kxmlguiClient)->setXMLGUIBuildDocument({});
+    const_cast<KXMLGUIClient *>(kxmlguiClient)->setXMLGUIBuildDocument({});
     return true;
 }
 
@@ -664,15 +661,13 @@ void KActionCollection::writeSettings(KConfigGroup *config, bool writeAll, QActi
         writeActions = actions();
     }
 
-    for (QMap<QString, QAction *>::ConstIterator it = d->actionByName.constBegin();
-            it != d->actionByName.constEnd(); ++it) {
-
+    for (QMap<QString, QAction *>::ConstIterator it = d->actionByName.constBegin(); it != d->actionByName.constEnd(); ++it) {
         QAction *action = it.value();
         if (!action) {
             continue;
         }
 
-        QString actionName = it.key();
+        const QString &actionName = it.key();
 
         // If the action name starts with unnamed- spit out a warning and ignore
         // it. That name will change at will and will break loading writing
@@ -720,7 +715,7 @@ void KActionCollection::slotActionTriggered()
 {
     QAction *action = qobject_cast<QAction *>(sender());
     if (action) {
-        emit actionTriggered(action);
+        Q_EMIT actionTriggered(action);
     }
 }
 
@@ -736,9 +731,9 @@ void KActionCollection::slotActionHovered()
     QAction *action = qobject_cast<QAction *>(sender());
     if (action) {
 #if KXMLGUI_BUILD_DEPRECATED_SINCE(5, 0)
-        emit actionHighlighted(action);
+        Q_EMIT actionHighlighted(action);
 #endif
-        emit actionHovered(action);
+        Q_EMIT actionHovered(action);
     }
 }
 
@@ -752,11 +747,11 @@ void KActionCollectionPrivate::_k_actionDestroyed(QObject *obj)
         return;
     }
 
-    //HACK the object we emit is partly destroyed
+    // HACK the object we emit is partly destroyed
 #if KXMLGUI_BUILD_DEPRECATED_SINCE(5, 0)
-    emit q->removed(action);
+    Q_EMIT q->removed(action);
 #endif
-    emit q->changed();
+    Q_EMIT q->changed();
 }
 
 void KActionCollection::connectNotify(const QMetaMethod &signal)
@@ -769,21 +764,19 @@ void KActionCollection::connectNotify(const QMetaMethod &signal)
 #if KXMLGUI_BUILD_DEPRECATED_SINCE(5, 0)
         signal.methodSignature() == "actionHighlighted(QAction*)" ||
 #endif
-            signal.methodSignature() == "actionHovered(QAction*)") {
+        signal.methodSignature() == "actionHovered(QAction*)") {
         if (!d->connectHovered) {
             d->connectHovered = true;
-            for (QAction *action : qAsConst(d->actions)) {
-                connect(action, &QAction::hovered,
-                        this, &KActionCollection::slotActionHovered);
+            for (QAction *action : std::as_const(d->actions)) {
+                connect(action, &QAction::hovered, this, &KActionCollection::slotActionHovered);
             }
         }
 
     } else if (signal.methodSignature() == "actionTriggered(QAction*)") {
         if (!d->connectTriggered) {
             d->connectTriggered = true;
-            for (QAction *action: qAsConst(d->actions)) {
-                connect(action, &QAction::triggered,
-                        this, &KActionCollection::slotActionTriggered);
+            for (QAction *action : std::as_const(d->actions)) {
+                connect(action, &QAction::triggered, this, &KActionCollection::slotActionTriggered);
             }
         }
     }
@@ -791,14 +784,14 @@ void KActionCollection::connectNotify(const QMetaMethod &signal)
     QObject::connectNotify(signal);
 }
 
-const QList< KActionCollection * > &KActionCollection::allCollections()
+const QList<KActionCollection *> &KActionCollection::allCollections()
 {
     return KActionCollectionPrivate::s_allCollections;
 }
 
 void KActionCollection::associateWidget(QWidget *widget) const
 {
-    for (QAction *action : qAsConst(d->actions)) {
+    for (QAction *action : std::as_const(d->actions)) {
         if (!widget->actions().contains(action)) {
             widget->addAction(action);
         }
@@ -811,18 +804,20 @@ void KActionCollection::addAssociatedWidget(QWidget *widget)
         widget->addActions(actions());
 
         d->associatedWidgets.append(widget);
-        connect(widget, SIGNAL(destroyed(QObject*)), this, SLOT(_k_associatedWidgetDestroyed(QObject*)));
+        connect(widget, &QObject::destroyed, this, [this](QObject *obj) {
+            d->_k_associatedWidgetDestroyed(obj);
+        });
     }
 }
 
 void KActionCollection::removeAssociatedWidget(QWidget *widget)
 {
-    for (QAction *action : qAsConst(d->actions)) {
+    for (QAction *action : std::as_const(d->actions)) {
         widget->removeAction(action);
     }
 
     d->associatedWidgets.removeAll(widget);
-    disconnect(widget, SIGNAL(destroyed(QObject*)), this, SLOT(_k_associatedWidgetDestroyed(QObject*)));
+    disconnect(widget, &QObject::destroyed, this, nullptr);
 }
 
 QAction *KActionCollectionPrivate::unlistAction(QAction *action)
@@ -859,15 +854,15 @@ QAction *KActionCollectionPrivate::unlistAction(QAction *action)
     return action;
 }
 
-QList< QWidget * > KActionCollection::associatedWidgets() const
+QList<QWidget *> KActionCollection::associatedWidgets() const
 {
     return d->associatedWidgets;
 }
 
 void KActionCollection::clearAssociatedWidgets()
 {
-    for (QWidget *widget : qAsConst(d->associatedWidgets)) {
-        for (QAction *action : qAsConst(d->actions)) {
+    for (QWidget *widget : std::as_const(d->associatedWidgets)) {
+        for (QAction *action : std::as_const(d->actions)) {
             widget->removeAction(action);
         }
     }
