@@ -17,37 +17,35 @@
 #include "kshortcutseditor.h"
 
 // The following is needed for KShortcutsEditorPrivate and QTreeWidgetHack
-#include "kshortcutsdialog_p.h"
 #include "debug.h"
+#include "kshortcutsdialog_p.h"
 
 #include <QAction>
 #include <QHeaderView>
 #include <QList>
 #include <QObject>
-#include <QTimer>
+#include <QPrintDialog>
+#include <QPrinter>
+#include <QTextCursor>
 #include <QTextDocument>
 #include <QTextTable>
-#include <QTextCursor>
 #include <QTextTableFormat>
-#include <QPrinter>
-#include <QPrintDialog>
+#include <QTimer>
 
-#include <kconfig.h>
-#include <kconfiggroup.h>
+#include <KConfig>
+#include <KConfigGroup>
 #if HAVE_GLOBALACCEL
-# include <kglobalaccel.h>
+#include <KGlobalAccel>
 #endif
-#include <kmessagebox.h>
-#include "kactioncollection.h"
 #include "kactioncategory.h"
-#include <ktreewidgetsearchline.h>
+#include "kactioncollection.h"
+#include <KTreeWidgetSearchLine>
 
 //---------------------------------------------------------------------
 // KShortcutsEditor
 //---------------------------------------------------------------------
 
-KShortcutsEditor::KShortcutsEditor(KActionCollection *collection, QWidget *parent, ActionTypes actionType,
-                                   LetterShortcuts allowLetterShortcuts)
+KShortcutsEditor::KShortcutsEditor(KActionCollection *collection, QWidget *parent, ActionTypes actionType, LetterShortcuts allowLetterShortcuts)
     : QWidget(parent)
     , d(new KShortcutsEditorPrivate(this))
 {
@@ -62,10 +60,7 @@ KShortcutsEditor::KShortcutsEditor(QWidget *parent, ActionTypes actionType, Lett
     d->initGUI(actionType, allowLetterShortcuts);
 }
 
-KShortcutsEditor::~KShortcutsEditor()
-{
-    delete d;
-}
+KShortcutsEditor::~KShortcutsEditor() = default;
 
 bool KShortcutsEditor::isModified() const
 {
@@ -145,7 +140,7 @@ void KShortcutsEditor::addCollection(KActionCollection *collection, const QStrin
     // sort the list
     d->ui.list->sortItems(Name, Qt::AscendingOrder);
 
-    // reenable updating
+    // re-enable updating
     setUpdatesEnabled(true);
 
     QTimer::singleShot(0, this, &KShortcutsEditor::resizeColumns);
@@ -185,14 +180,14 @@ void KShortcutsEditor::exportConfiguration(KConfigBase *config) const
     if (d->actionTypes & KShortcutsEditor::GlobalAction) {
         QString groupName(QStringLiteral("Global Shortcuts"));
         KConfigGroup group(config, groupName);
-        for (KActionCollection *collection : qAsConst(d->actionCollections)) {
+        for (KActionCollection *collection : std::as_const(d->actionCollections)) {
             collection->exportGlobalShortcuts(&group, true);
         }
     }
     if (d->actionTypes & ~KShortcutsEditor::GlobalAction) {
         QString groupName(QStringLiteral("Shortcuts"));
         KConfigGroup group(config, groupName);
-        for (KActionCollection *collection : qAsConst(d->actionCollections)) {
+        for (KActionCollection *collection : std::as_const(d->actionCollections)) {
             collection->writeSettings(&group, true);
         }
     }
@@ -200,12 +195,12 @@ void KShortcutsEditor::exportConfiguration(KConfigBase *config) const
 
 void KShortcutsEditor::writeConfiguration(KConfigGroup *config) const
 {
-    for (KActionCollection *collection : qAsConst(d->actionCollections)) {
+    for (KActionCollection *collection : std::as_const(d->actionCollections)) {
         collection->writeSettings(config);
     }
 }
 
-//slot
+// slot
 void KShortcutsEditor::resizeColumns()
 {
     for (int i = 0; i < d->ui.list->columnCount(); i++) {
@@ -241,9 +236,9 @@ void KShortcutsEditor::undoChanges()
 
 void KShortcutsEditor::undo()
 {
-    //This function used to crash sometimes when invoked by clicking on "cancel"
-    //with Qt 4.2.something. Apparently items were deleted too early by Qt.
-    //It seems to work with 4.3-ish Qt versions. Keep an eye on this.
+    // This function used to crash sometimes when invoked by clicking on "cancel"
+    // with Qt 4.2.something. Apparently items were deleted too early by Qt.
+    // It seems to work with 4.3-ish Qt versions. Keep an eye on this.
     for (QTreeWidgetItemIterator it(d->ui.list); (*it); ++it) {
         if (KShortcutsEditorItem *item = dynamic_cast<KShortcutsEditorItem *>(*it)) {
             item->undo();
@@ -251,9 +246,9 @@ void KShortcutsEditor::undo()
     }
 }
 
-//We ask the user here if there are any conflicts, as opposed to undo().
-//They don't do the same thing anyway, this just not to confuse any readers.
-//slot
+// We ask the user here if there are any conflicts, as opposed to undo().
+// They don't do the same thing anyway, this just not to confuse any readers.
+// slot
 void KShortcutsEditor::allDefault()
 {
     d->allDefault();
@@ -278,10 +273,11 @@ void KShortcutsEditor::setActionTypes(ActionTypes actionTypes)
 // KShortcutsEditorPrivate
 //---------------------------------------------------------------------
 
-KShortcutsEditorPrivate::KShortcutsEditorPrivate(KShortcutsEditor *q)
-    :   q(q),
-        delegate(nullptr)
-{}
+KShortcutsEditorPrivate::KShortcutsEditorPrivate(KShortcutsEditor *qq)
+    : q(qq)
+    , delegate(nullptr)
+{
+}
 
 void KShortcutsEditorPrivate::initGUI(KShortcutsEditor::ActionTypes types, KShortcutsEditor::LetterShortcuts allowLetterShortcuts)
 {
@@ -291,7 +287,7 @@ void KShortcutsEditorPrivate::initGUI(KShortcutsEditor::ActionTypes types, KShor
     q->layout()->setContentsMargins(0, 0, 0, 0);
     ui.searchFilter->searchLine()->setTreeWidget(ui.list); // Plug into search line
     ui.list->header()->setSectionResizeMode(QHeaderView::ResizeToContents);
-    ui.list->header()->hideSection(ShapeGesture);  //mouse gestures didn't make it in time...
+    ui.list->header()->hideSection(ShapeGesture); // mouse gestures didn't make it in time...
     ui.list->header()->hideSection(RockerGesture);
 #if HAVE_GLOBALACCEL
     bool hideGlobals = !(actionTypes & KShortcutsEditor::GlobalAction);
@@ -309,23 +305,21 @@ void KShortcutsEditorPrivate::initGUI(KShortcutsEditor::ActionTypes types, KShor
 
     // Create the Delegate. It is responsible for the KKeySeqeunceWidgets that
     // really change the shortcuts.
-    delegate = new KShortcutsEditorDelegate(
-        ui.list,
-        allowLetterShortcuts == KShortcutsEditor::LetterShortcutsAllowed);
+    delegate = new KShortcutsEditorDelegate(ui.list, allowLetterShortcuts == KShortcutsEditor::LetterShortcutsAllowed);
 
     ui.list->setItemDelegate(delegate);
     ui.list->setSelectionBehavior(QAbstractItemView::SelectItems);
     ui.list->setSelectionMode(QAbstractItemView::SingleSelection);
-    //we have our own editing mechanism
+    // we have our own editing mechanism
     ui.list->setEditTriggers(QAbstractItemView::NoEditTriggers);
     ui.list->setAlternatingRowColors(true);
 
-    //TODO listen to changes to global shortcuts
-    QObject::connect(delegate, SIGNAL(shortcutChanged(QVariant,QModelIndex)),
-                     q, SLOT(capturedShortcut(QVariant,QModelIndex)));
-    //hide the editor widget chen its item becomes hidden
-    QObject::connect(ui.searchFilter->searchLine(), &KTreeWidgetSearchLine::hiddenChanged,
-                     delegate, &KShortcutsEditorDelegate::hiddenBySearchLine);
+    // TODO listen to changes to global shortcuts
+    QObject::connect(delegate, &KShortcutsEditorDelegate::shortcutChanged, q, [this](const QVariant &newShortcut, const QModelIndex &index) {
+        capturedShortcut(newShortcut, index);
+    });
+    // hide the editor widget chen its item becomes hidden
+    QObject::connect(ui.searchFilter->searchLine(), &KTreeWidgetSearchLine::hiddenChanged, delegate, &KShortcutsEditorDelegate::hiddenBySearchLine);
 
     ui.searchFilter->setFocus();
 }
@@ -384,7 +378,7 @@ void KShortcutsEditorPrivate::allDefault()
         KShortcutsEditorItem *item = static_cast<KShortcutsEditorItem *>(*it);
         QAction *act = item->m_action;
 
-        QList<QKeySequence> defaultShortcuts = act->property("defaultShortcuts").value<QList<QKeySequence> >();
+        QList<QKeySequence> defaultShortcuts = act->property("defaultShortcuts").value<QList<QKeySequence>>();
         if (act->shortcuts() != defaultShortcuts) {
             QKeySequence primary = defaultShortcuts.isEmpty() ? QKeySequence() : defaultShortcuts.at(0);
             QKeySequence alternate = defaultShortcuts.size() <= 1 ? QKeySequence() : defaultShortcuts.at(1);
@@ -402,9 +396,8 @@ void KShortcutsEditorPrivate::allDefault()
     }
 }
 
-//static
-KShortcutsEditorItem *KShortcutsEditorPrivate::itemFromIndex(QTreeWidget *const w,
-        const QModelIndex &index)
+// static
+KShortcutsEditorItem *KShortcutsEditorPrivate::itemFromIndex(QTreeWidget *const w, const QModelIndex &index)
 {
     QTreeWidgetItem *item = static_cast<QTreeWidgetHack *>(w)->itemFromIndex(index);
     if (item && item->type() == ActionItem) {
@@ -428,10 +421,10 @@ QTreeWidgetItem *KShortcutsEditorPrivate::findOrMakeItem(QTreeWidgetItem *parent
     return ret;
 }
 
-//private slot
+// private slot
 void KShortcutsEditorPrivate::capturedShortcut(const QVariant &newShortcut, const QModelIndex &index)
 {
-    //dispatch to the right handler
+    // dispatch to the right handler
     if (!index.isValid()) {
         return;
     }
@@ -452,8 +445,8 @@ void KShortcutsEditorPrivate::changeKeyShortcut(KShortcutsEditorItem *item, uint
     }
 
     item->setKeySequence(column, capture);
-    emit q->keyChange();
-    //force view update
+    Q_EMIT q->keyChange();
+    // force view update
     item->setText(column, capture.toString(QKeySequence::NativeText));
 }
 
@@ -466,10 +459,10 @@ void KShortcutsEditorPrivate::clearConfiguration()
 
         KShortcutsEditorItem *item = static_cast<KShortcutsEditorItem *>(*it);
 
-        changeKeyShortcut(item, LocalPrimary,   QKeySequence());
+        changeKeyShortcut(item, LocalPrimary, QKeySequence());
         changeKeyShortcut(item, LocalAlternate, QKeySequence());
 
-        changeKeyShortcut(item, GlobalPrimary,   QKeySequence());
+        changeKeyShortcut(item, GlobalPrimary, QKeySequence());
         changeKeyShortcut(item, GlobalAlternate, QKeySequence());
     }
 }
@@ -483,17 +476,16 @@ void KShortcutsEditorPrivate::importConfiguration(KConfigBase *config)
 
     KConfigGroup globalShortcutsGroup(config, QStringLiteral("Global Shortcuts"));
     if ((actionTypes & KShortcutsEditor::GlobalAction) && globalShortcutsGroup.exists()) {
-
         for (QTreeWidgetItemIterator it(ui.list); (*it); ++it) {
-
             if (!(*it)->parent()) {
                 continue;
             }
 
             KShortcutsEditorItem *item = static_cast<KShortcutsEditorItem *>(*it);
             const QString actionId = item->data(Id).toString();
-            if (!globalShortcutsGroup.hasKey(actionId))
+            if (!globalShortcutsGroup.hasKey(actionId)) {
                 continue;
+            }
 
             QList<QKeySequence> sc = QKeySequence::listFromString(globalShortcutsGroup.readEntry(actionId, QString()));
             changeKeyShortcut(item, GlobalPrimary, primarySequence(sc));
@@ -504,14 +496,14 @@ void KShortcutsEditorPrivate::importConfiguration(KConfigBase *config)
     if (actionTypes & ~KShortcutsEditor::GlobalAction) {
         const KConfigGroup localShortcutsGroup(config, QStringLiteral("Shortcuts"));
         for (QTreeWidgetItemIterator it(ui.list); (*it); ++it) {
-
             if (!(*it)->parent()) {
                 continue;
             }
             KShortcutsEditorItem *item = static_cast<KShortcutsEditorItem *>(*it);
             const QString actionId = item->data(Id).toString();
-            if (!localShortcutsGroup.hasKey(actionId))
+            if (!localShortcutsGroup.hasKey(actionId)) {
                 continue;
+            }
 
             QList<QKeySequence> sc = QKeySequence::listFromString(localShortcutsGroup.readEntry(actionId, QString()));
             changeKeyShortcut(item, LocalPrimary, primarySequence(sc));
@@ -540,7 +532,7 @@ more important things):
 */
 void KShortcutsEditorPrivate::printShortcuts() const
 {
-// One cant print on wince
+// One can't print on wince
 #ifndef _WIN32_WCE
     QTreeWidgetItem *root = ui.list->invisibleRootItem();
     QTextDocument doc;
@@ -552,9 +544,7 @@ void KShortcutsEditorPrivate::printShortcuts() const
     QTextCharFormat headerFormat;
     headerFormat.setProperty(QTextFormat::FontSizeAdjustment, 3);
     headerFormat.setFontWeight(QFont::Bold);
-    cursor.insertText(i18nc("header for an applications shortcut list", "Shortcuts for %1",
-                            QGuiApplication::applicationDisplayName()),
-                      headerFormat);
+    cursor.insertText(i18nc("header for an applications shortcut list", "Shortcuts for %1", QGuiApplication::applicationDisplayName()), headerFormat);
     QTextCharFormat componentFormat;
     componentFormat.setProperty(QTextFormat::FontSizeAdjustment, 2);
     componentFormat.setFontWeight(QFont::Bold);
